diff --exclude .svn -ur x264.r502/encoder/encoder.c x264.work/encoder/encoder.c
--- x264.r502/encoder/encoder.c	2006-04-05 04:40:49.000000000 +0200
+++ x264.work/encoder/encoder.c	2006-04-19 08:27:54.000000000 +0200
@@ -632,6 +632,8 @@
             ( h->mb.b_lossless || h->param.analyse.i_subpel_refine <= 1 ) ? h->pixf.sad : h->pixf.satd,
             sizeof(h->pixf.mbcmp) );
 
+    x264_ratecontrol_reconfig( h, param );
+
     return x264_validate_parameters( h );
 }
 
diff --exclude .svn -ur x264.r502/encoder/ratecontrol.c x264.work/encoder/ratecontrol.c
--- x264.r502/encoder/ratecontrol.c	2006-04-05 04:40:49.000000000 +0200
+++ x264.work/encoder/ratecontrol.c	2006-04-19 08:52:37.000000000 +0200
@@ -531,6 +531,41 @@
     }
 }
 
+void x264_ratecontrol_reconfig( x264_t *h, x264_param_t *param )
+{
+    x264_ratecontrol_t *rc = h->rc;
+    
+    /* Only CBR in single pass mode */
+    if( h->param.rc.b_cbr && !h->param.rc.b_stat_read )
+    {
+        /* Change the bitrate */
+        h->param.rc.i_bitrate = param->rc.i_bitrate;
+        rc->bitrate = h->param.rc.i_bitrate * 1000;
+        
+        if( h->param.rc.i_vbv_max_bitrate < h->param.rc.i_bitrate &&
+            h->param.rc.i_vbv_max_bitrate > 0)
+        {
+            x264_log(h, X264_LOG_ERROR, "max bitrate less than average bitrate, ignored.\n");
+            rc->b_vbv = 0;
+            rc->cbr_decay = 1.0;
+        }
+        else if( h->param.rc.i_vbv_max_bitrate > 0 &&
+                 h->param.rc.i_vbv_buffer_size > 0 )
+        {
+            if( h->param.rc.i_vbv_buffer_size < 3 * h->param.rc.i_vbv_max_bitrate / rc->fps ) {
+                h->param.rc.i_vbv_buffer_size = 3 * h->param.rc.i_vbv_max_bitrate / rc->fps;
+                x264_log( h, X264_LOG_ERROR, "VBV buffer size too small, using %d kbit\n",
+                          h->param.rc.i_vbv_buffer_size );
+            }
+            rc->buffer_rate = h->param.rc.i_vbv_max_bitrate * 1000 / rc->fps;
+            rc->buffer_size = h->param.rc.i_vbv_buffer_size * 1000;
+            rc->cbr_decay = 1.0 - rc->buffer_rate / rc->buffer_size
+                          * 0.5 * X264_MAX(0, 1.5 - rc->buffer_rate * rc->fps / rc->bitrate);
+            rc->b_vbv = 1;
+        }
+    }
+}
+
 void x264_ratecontrol_delete( x264_t *h )
 {
     x264_ratecontrol_t *rc = h->rc;
diff --exclude .svn -ur x264.r502/encoder/ratecontrol.h x264.work/encoder/ratecontrol.h
--- x264.r502/encoder/ratecontrol.h	2006-04-05 04:40:49.000000000 +0200
+++ x264.work/encoder/ratecontrol.h	2006-04-19 08:37:22.000000000 +0200
@@ -26,6 +26,7 @@
 
 int  x264_ratecontrol_new   ( x264_t * );
 void x264_ratecontrol_delete( x264_t * );
+void x264_ratecontrol_reconfig( x264_t *, x264_param_t * );
 
 void x264_ratecontrol_start( x264_t *, int i_slice_type, int i_force_qp );
 void x264_ratecontrol_threads_start( x264_t * );
